@@ -108,7 +108,6 @@ typedef struct cred {		/* maps to task field: */
     int cr_ngroups;
 } cred_t;
 #define AFS_UCRED cred
-#define AFS_PROC struct task_struct
 #define crhold(c) (c)->cr_ref++
 
 /* UIO manipulation */
@@ -117,7 +116,7 @@ typedef enum { UIO_READ, UIO_WRITE } uio_flag_t;
 typedef struct uio {
     struct  	iovec *uio_iov;
     int     	uio_iovcnt;
-    int     	uio_offset;
+    afs_offs_t 	uio_offset;
     uio_seg_t   uio_seg;
     int     	uio_resid;
     uio_flag_t 	uio_flag;
