@@ -22,7 +22,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_readdir.c,v 1.8.4.3 2002/11/22 19:14:53 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_readdir.c,v 1.14 2002/04/09 19:21:59 kolya Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -283,7 +283,7 @@ ssize_t			rlen;
 #else
 int			rlen;
 #endif
-int			off;
+afs_size_t		off;
 {
     int	code = 0;
 #if	defined(AFS_SUN56_ENV)
@@ -473,10 +473,12 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #endif
     OSI_VC_DECL(avc);
     struct uio *auio;
-    struct AFS_UCRED *acred; {
+    struct AFS_UCRED *acred; 
+{
     struct vrequest treq;
     register struct dcache *tdc;
-    afs_int32 origOffset, len, dirsiz;
+    afs_size_t origOffset, tlen;
+    afs_int32 len, dirsiz;
     int code = 0;
     struct DirEntry *ode = 0, *nde = 0;
     int o_slen = 0, n_slen = 0;
@@ -541,12 +543,14 @@ tagain:
     code = afs_VerifyVCache(avc, &treq);
     if (code) goto done;
     /* get a reference to the entire directory */
-    tdc = afs_GetDCache(avc, 0, &treq, &origOffset, &len, 1);
+    tdc = afs_GetDCache(avc, (afs_size_t) 0, &treq, &origOffset, &tlen, 1);
+    len = tlen;
     if (!tdc) {
 	code = ENOENT;
 	goto done;
     }
     ObtainReadLock(&avc->lock);
+    ObtainReadLock(&tdc->lock);
 
     /*
      * Make sure that the data in the cache is current. There are two
@@ -555,15 +559,22 @@ tagain:
      * 2. The cache data is no longer valid
      */
     while ((avc->states & CStatd)
-	   && (tdc->flags & DFFetching)
+	   && (tdc->dflags & DFFetching)
 	   && hsame(avc->m.DataVersion, tdc->f.versionNo)) {
-	tdc->flags |= DFWaiting;
+	afs_Trace4(afs_iclSetp, CM_TRACE_DCACHEWAIT,
+			ICL_TYPE_STRING, __FILE__,
+			ICL_TYPE_INT32, __LINE__,
+			ICL_TYPE_POINTER, tdc,
+			ICL_TYPE_INT32, tdc->dflags);
+	ReleaseReadLock(&tdc->lock);
 	ReleaseReadLock(&avc->lock);
 	afs_osi_Sleep(&tdc->validPos);
 	ObtainReadLock(&avc->lock);
+	ObtainReadLock(&tdc->lock);
     }
     if (!(avc->states & CStatd)
 	|| !hsame(avc->m.DataVersion, tdc->f.versionNo)) {
+	ReleaseReadLock(&tdc->lock);
 	ReleaseReadLock(&avc->lock);
 	afs_PutDCache(tdc);
 	goto tagain;
@@ -764,6 +775,7 @@ tagain:
     if (ode) DRelease(ode, 0);
 
 dirend:
+    ReleaseReadLock(&tdc->lock);
     afs_PutDCache(tdc);
     ReleaseReadLock(&avc->lock);
 
@@ -783,12 +795,12 @@ afs1_readdir(avc, auio, acred, eofp)
 #else
 afs1_readdir(avc, auio, acred)
 #endif
-    struct vcache *avc;
+    register struct vcache *avc;
     struct uio *auio;
     struct AFS_UCRED *acred; {
     struct vrequest treq;
     register struct dcache *tdc;
-    afs_int32 origOffset, len;
+    afs_size_t origOffset, len;
     int code = 0;
     struct DirEntry *ode = 0, *nde = 0;
     int o_slen = 0, n_slen = 0;
@@ -828,12 +840,13 @@ tagain:
     code = afs_VerifyVCache(avc, &treq);
     if (code) goto done;
     /* get a reference to the entire directory */
-    tdc = afs_GetDCache(avc, 0, &treq, &origOffset, &len, 1);
+    tdc = afs_GetDCache(avc, (afs_size_t) 0, &treq, &origOffset, &len, 1);
     if (!tdc) {
 	code = ENOENT;
 	goto done;
     }
     ObtainReadLock(&avc->lock);
+    ObtainReadLock(&tdc->lock);
 
     /*
      * Make sure that the data in the cache is current. There are two
@@ -842,15 +855,22 @@ tagain:
      * 2. The cache data is no longer valid
      */
     while ((avc->states & CStatd)
-	   && (tdc->flags & DFFetching)
+	   && (tdc->dflags & DFFetching)
 	   && hsame(avc->m.DataVersion, tdc->f.versionNo)) {
-	tdc->flags |= DFWaiting;
+	afs_Trace4(afs_iclSetp, CM_TRACE_DCACHEWAIT,
+			ICL_TYPE_STRING, __FILE__,
+			ICL_TYPE_INT32, __LINE__,
+			ICL_TYPE_POINTER, tdc,
+			ICL_TYPE_INT32, tdc->dflags);
+	ReleaseReadLock(&tdc->lock);
 	ReleaseReadLock(&avc->lock);
 	afs_osi_Sleep(&tdc->validPos);
 	ObtainReadLock(&avc->lock);
+	ObtainReadLock(&tdc->lock);
     }
     if (!(avc->states & CStatd)
 	|| !hsame(avc->m.DataVersion, tdc->f.versionNo)) {
+	ReleaseReadLock(&tdc->lock);
 	ReleaseReadLock(&avc->lock);
 	afs_PutDCache(tdc);
 	goto tagain;
@@ -1001,6 +1021,7 @@ tagain:
     if (ode) DRelease(ode, 0);
 
 dirend:
+    ReleaseReadLock(&tdc->lock);
     afs_PutDCache(tdc);
     ReleaseReadLock(&avc->lock);
 
