@@ -16,7 +16,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/afs_callback.c,v 1.6.2.10 2003/03/06 15:39:43 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/afs_callback.c,v 1.13 2002/03/18 02:51:13 kolya Exp $");
 
 #include "../afs/sysincludes.h" /*Standard vendor system headers*/
 #include "../afs/afsincludes.h" /*AFS-based standard headers*/
@@ -109,9 +109,7 @@ int SRXAFSCB_GetCE(a_call, a_index, a_result)
     int code;				/*Return code*/
     XSTATS_DECLS;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
 
     XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_GETCE);
 
@@ -153,7 +151,11 @@ int SRXAFSCB_GetCE(a_call, a_index, a_result)
     a_result->lock.pid_writer = 0;
     a_result->lock.src_indicator = 0;
 #endif /* AFS_OSF20_ENV */
+#ifdef AFS_64BIT_CLIENT
+    a_result->Length = (afs_int32) tvc->m.Length & 0xffffffff;
+#else /* AFS_64BIT_CLIENT */
     a_result->Length = tvc->m.Length;
+#endif /* AFS_64BIT_CLIENT */
     a_result->DataVersion = hgetlo(tvc->m.DataVersion);
     a_result->callback = afs_data_pointer_to_int32(tvc->callback);		/* XXXX Now a pointer; change it XXXX */
     a_result->cbExpires = tvc->cbExpires;
@@ -170,14 +172,98 @@ int SRXAFSCB_GetCE(a_call, a_index, a_result)
 fcnDone:
     XSTATS_END_TIME;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return(code);
 
 } /*SRXAFSCB_GetCE*/
 
+int SRXAFSCB_GetCE64(a_call, a_index, a_result)
+    struct rx_call *a_call;
+    afs_int32 a_index;
+    struct AFSDBCacheEntry64 *a_result;
+
+{ /*SRXAFSCB_GetCE64*/
+
+    register int i;			/*Loop variable*/
+    register struct vcache *tvc;	/*Ptr to current cache entry*/
+    int code;				/*Return code*/
+    XSTATS_DECLS;
+
+    RX_AFS_GLOCK();
+
+    XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_GETCE);
+
+    AFS_STATCNT(SRXAFSCB_GetCE64);
+    for (i = 0; i < VCSIZE; i++) {
+	for (tvc = afs_vhashT[i]; tvc; tvc = tvc->hnext) {
+	    if (a_index == 0)
+		goto searchDone;
+	    a_index--;
+	} /*Zip through current hash chain*/
+    } /*Zip through hash chains*/
+
+  searchDone:
+    if (tvc == (struct vcache *) 0) {
+	/*Past EOF*/
+	code = 1;
+	goto fcnDone;
+    }
+
+    /*
+     * Copy out the located entry.
+     */
+    a_result->addr = afs_data_pointer_to_int32(tvc);
+    a_result->cell = tvc->fid.Cell;
+    a_result->netFid.Volume = tvc->fid.Fid.Volume;
+    a_result->netFid.Vnode = tvc->fid.Fid.Vnode;
+    a_result->netFid.Unique = tvc->fid.Fid.Unique;
+    a_result->lock.waitStates = tvc->lock.wait_states;
+    a_result->lock.exclLocked = tvc->lock.excl_locked;
+    a_result->lock.readersReading = tvc->lock.readers_reading;
+    a_result->lock.numWaiting = tvc->lock.num_waiting;
+#if defined(INSTRUMENT_LOCKS)
+    a_result->lock.pid_last_reader = tvc->lock.pid_last_reader;
+    a_result->lock.pid_writer = tvc->lock.pid_writer;
+    a_result->lock.src_indicator = tvc->lock.src_indicator;
+#else
+    /* On osf20 , the vcache does not maintain these three fields */
+    a_result->lock.pid_last_reader = 0;
+    a_result->lock.pid_writer = 0;
+    a_result->lock.src_indicator = 0;
+#endif /* AFS_OSF20_ENV */
+#ifdef AFS_64BIT_ENV
+    a_result->Length = tvc->m.Length;
+#else /* AFS_64BIT_ENV */
+#ifdef AFS_64BIT_CLIENT
+    a_result->Length = tvc->m.Length;
+#else /* AFS_64BIT_CLIENT */
+    a_result->Length.high = 0;
+    a_result->Length.low = tvc->m.Length;
+#endif /* AFS_64BIT_CLIENT */
+#endif /* AFS_64BIT_ENV */
+    a_result->DataVersion = hgetlo(tvc->m.DataVersion);
+    a_result->callback = afs_data_pointer_to_int32(tvc->callback);		/* XXXX Now a pointer; change it XXXX */
+    a_result->cbExpires = tvc->cbExpires;
+    a_result->refCount = VREFCOUNT(tvc);
+    a_result->opens = tvc->opens;
+    a_result->writers = tvc->execsOrWriters;
+    a_result->mvstat = tvc->mvstat;
+    a_result->states = tvc->states;
+    code = 0;
+
+    /*
+     * Return our results.
+     */
+fcnDone:
+    XSTATS_END_TIME;
+
+    RX_AFS_GUNLOCK();
+
+    return(code);
+
+} /*SRXAFSCB_GetCE64*/
+
 
 /*------------------------------------------------------------------------
  * EXPORTED SRXAFSCB_GetLock
@@ -215,9 +301,7 @@ int SRXAFSCB_GetLock (a_call, a_index, a_result)
     int code;			/*Return code*/
     XSTATS_DECLS;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
 
     XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_GETLOCK);
     
@@ -253,9 +337,7 @@ int SRXAFSCB_GetLock (a_call, a_index, a_result)
 
     XSTATS_END_TIME;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return(code);
 
@@ -435,9 +517,7 @@ int SRXAFSCB_CallBack(a_call, a_fids, a_callbacks)
     int code=0;
     XSTATS_DECLS;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
 
     XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_CALLBACK);
 
@@ -454,9 +534,7 @@ int SRXAFSCB_CallBack(a_call, a_fids, a_callbacks)
 
     XSTATS_END_TIME;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
     
     return(0);
 
@@ -491,17 +569,13 @@ int SRXAFSCB_Probe(a_call)
     int code = 0;
     XSTATS_DECLS;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
     AFS_STATCNT(SRXAFSCB_Probe);
 
     XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_PROBE);
     XSTATS_END_TIME;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return(0);
 
@@ -542,9 +616,7 @@ int SRXAFSCB_InitCallBackState(a_call)
     extern int osi_dnlc_purge();
     XSTATS_DECLS;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
 
     XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_INITCALLBACKSTATE);
     AFS_STATCNT(SRXAFSCB_InitCallBackState);
@@ -591,9 +663,7 @@ int SRXAFSCB_InitCallBackState(a_call)
 
     XSTATS_END_TIME;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return(0);
 
@@ -630,18 +700,14 @@ int SRXAFSCB_XStatsVersion(a_call, a_versionP)
 
     XSTATS_DECLS;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
     XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_XSTATSVERSION);
 
     *a_versionP = AFSCB_XSTAT_VERSION;
 
     XSTATS_END_TIME;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return(0);
 }  /*SRXAFSCB_XStatsVersion*/
@@ -689,9 +755,7 @@ int SRXAFSCB_GetXStats(a_call, a_clientVersionNum, a_collectionNumber, a_srvVers
     afs_int32 dataBytes;		/*Bytes in data buffer*/
     XSTATS_DECLS;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
 
     XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_GETXSTATS);
 
@@ -785,9 +849,7 @@ int SRXAFSCB_GetXStats(a_call, a_clientVersionNum, a_collectionNumber, a_srvVers
 
     XSTATS_END_TIME;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return(code);
 
@@ -928,9 +990,7 @@ struct interfaceAddr *addr;
     int code = 0;
     XSTATS_DECLS;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
 
     AFS_STATCNT(SRXAFSCB_WhoAreYou);
 
@@ -947,9 +1007,7 @@ struct interfaceAddr *addr;
 
     ReleaseReadLock(&afs_xinterface);
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return code;
 }
@@ -1020,9 +1078,7 @@ afsUUID *a_uuid;
     int code = 0;
     XSTATS_DECLS;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
     AFS_STATCNT(SRXAFSCB_Probe);
 
     XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_PROBE);
@@ -1030,9 +1086,7 @@ afsUUID *a_uuid;
 	code = 1; /* failure */
     XSTATS_END_TIME;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return code;
 }
@@ -1070,9 +1124,7 @@ int SRXAFSCB_GetServerPrefs(
     int i, j;
     struct srvAddr *sa;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
     AFS_STATCNT(SRXAFSCB_GetServerPrefs);
 
     ObtainReadLock(&afs_xserver);
@@ -1091,9 +1143,7 @@ int SRXAFSCB_GetServerPrefs(
 
     ReleaseReadLock(&afs_xserver);
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return 0;
 }
@@ -1125,42 +1175,38 @@ int SRXAFSCB_GetCellServDB(
     struct rx_call *a_call,
     afs_int32 a_index,
     char **a_name,
-    serverList *a_hosts)
+    afs_int32 *a_hosts)
 {
     afs_int32 i, j;
     struct cell *tcell;
     struct afs_q *cq, *tq;
     char *t_name, *p_name = NULL;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
     AFS_STATCNT(SRXAFSCB_GetCellServDB);
 
-    tcell = afs_GetCellByIndex(a_index, READ_LOCK);
+    memset(a_hosts, 0, AFSMAXCELLHOSTS * sizeof(afs_int32));
+
+    /* search the list for the cell with this index */
+    ObtainReadLock(&afs_xcell);
+
+    tcell = afs_GetCellByIndex(a_index, READ_LOCK, 0);
 
     if (!tcell) {
-      i = 0;
-      a_hosts->serverList_val = 0;
-      a_hosts->serverList_len = 0;
+	i = 0;
     } else {
-      p_name = tcell->cellName;
-      for (j = 0 ; j < AFSMAXCELLHOSTS && tcell->cellHosts[j] ; j++)
-	;
-      i = strlen(p_name);
-      a_hosts->serverList_val = (afs_int32 *)afs_osi_Alloc(j*sizeof(afs_int32));
-      a_hosts->serverList_len = j;
-      for (j = 0 ; j < AFSMAXCELLHOSTS && tcell->cellHosts[j] ; j++)
-	a_hosts->serverList_val[j] = ntohl(tcell->cellHosts[j]->addr->sa_ip);
-      afs_PutCell(tcell, READ_LOCK);
+	p_name = tcell->cellName;
+	for (j = 0 ; j < AFSMAXCELLHOSTS && tcell->cellHosts[j] ; j++) {
+	    a_hosts[j] = ntohl(tcell->cellHosts[j]->addr->sa_ip);
+	}
+	i = strlen(p_name);
+	afs_PutCell(tcell, READ_LOCK);
     }
 
-    t_name = (char *)afs_osi_Alloc(i+1);
+    t_name = (char *)rxi_Alloc(i+1);
     if (t_name == NULL) {
-      afs_osi_Free(a_hosts->serverList_val, (j*sizeof(afs_int32)));
-#ifdef RX_ENABLE_LOCKS
-	AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+	ReleaseReadLock(&afs_xcell);
+	RX_AFS_GUNLOCK();
 	return ENOMEM;
     }
 
@@ -1168,9 +1214,9 @@ int SRXAFSCB_GetCellServDB(
     if (p_name)
 	memcpy(t_name, p_name, i);
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    ReleaseReadLock(&afs_xcell);
+
+    RX_AFS_GUNLOCK();
 
     *a_name = t_name;
     return 0;
@@ -1203,29 +1249,37 @@ int SRXAFSCB_GetLocalCell(
 {
     int plen;
     struct cell *tcell;
+    struct afs_q *cq, *tq;
     char *t_name, *p_name = NULL;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
     AFS_STATCNT(SRXAFSCB_GetLocalCell);
 
     /* Search the list for the primary cell. Cell number 1 is only
      * the primary cell is when no other cell is explicitly marked as
      * the primary cell.  */
-    tcell = afs_GetPrimaryCell(READ_LOCK);
-    if (tcell)
-	p_name = tcell->cellName;
+    ObtainReadLock(&afs_xcell);
+
+    for (cq = CellLRU.next; cq != &CellLRU; cq = tq) {
+        tq = QNext(cq);
+	tcell = QTOC(cq);
+	if (tcell->states & CPrimary) {
+	    p_name = tcell->cellName;
+	    break;
+	}
+        if (tcell->cell == 1) {
+	    p_name = tcell->cellName;
+	}
+    }
+
     if (p_name)
 	plen = strlen(p_name);
     else
 	plen = 0;
-    t_name = (char *)afs_osi_Alloc(plen+1);
+    t_name = (char *)rxi_Alloc(plen+1);
     if (t_name == NULL) {
-	if (tcell) afs_PutCell(tcell, READ_LOCK);
-#ifdef RX_ENABLE_LOCKS
-	AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+	ReleaseReadLock(&afs_xcell);
+	RX_AFS_GUNLOCK();
 	return ENOMEM;
     }
 
@@ -1233,12 +1287,11 @@ int SRXAFSCB_GetLocalCell(
     if (p_name)
 	memcpy(t_name, p_name, plen);
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    ReleaseReadLock(&afs_xcell);
+
+    RX_AFS_GUNLOCK();
 
     *a_name = t_name;
-    if (tcell) afs_PutCell(tcell, READ_LOCK);
     return 0;
 }
 
@@ -1316,20 +1369,16 @@ int SRXAFSCB_GetCacheConfig(
     size_t allocsize;
     cm_initparams_v1 cm_config;
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
     AFS_STATCNT(SRXAFSCB_GetCacheConfig);
 
     /*
      * Currently only support version 1
      */
     allocsize = sizeof(cm_initparams_v1);
-    t_config = (afs_uint32 *)afs_osi_Alloc(allocsize);
+    t_config = (afs_uint32 *)rxi_Alloc(allocsize);
     if (t_config == NULL) {
-#ifdef RX_ENABLE_LOCKS
-	AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+	RX_AFS_GUNLOCK();
 	return ENOMEM;
     }
 
@@ -1350,75 +1399,78 @@ int SRXAFSCB_GetCacheConfig(
     config->cacheConfig_val = t_config;
     config->cacheConfig_len = allocsize/sizeof(afs_uint32);
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
 
     return 0;
 }
 
 /*------------------------------------------------------------------------
- * EXPORTED SRXAFSCB_GetCellByNum
+ * EXPORTED SRXAFSCB_FetchData
  *
  * Description:
- *	Routine to get information about a cell specified by its
- *	cell number (returned by GetCE/GetCE64).
+ *      Routine to do third party move from a remioserver to the original
+ *      issuer of an ArchiveData request. Presently supported only by the
+ *      "fs" command, not by the AFS client.
  *
  * Arguments:
- *	a_call    : Ptr to Rx call on which this request came in.
- *	a_cellnum : Input cell number
- *	a_name    : Output cell name (one zero byte when no such cell).
- *	a_hosts   : Output cell database servers in host byte order.
+ *      rxcall:        Ptr to Rx call on which this request came in.
+ *      Fid:           pointer to AFSFid structure.
+ *      Fd:            File descriptor inside fs command.
+ *      Position:      Offset in the file.
+ *      Length:        Data length to transfer.
+ *      TotalLength:   Pointer to total file length field
  *
  * Returns:
- *	0 on success
+ *      0 on success
  *
  * Environment:
- *	Nothing interesting.
+ *      Nothing interesting.
  *
  * Side Effects:
- *	As advertised.
  *------------------------------------------------------------------------*/
-
-int SRXAFSCB_GetCellByNum(struct rx_call *a_call, afs_int32 a_cellnum,
-    char **a_name, serverList *a_hosts)
+SRXAFSCB_FetchData(rxcall, Fid, Fd, Position, Length, TotalLength)
+    struct rx_call *rxcall;
+    struct AFSFid *Fid;
+    afs_int32 Fd;
+    afs_int64 Position;
+    afs_int64 Length;
+    afs_int64 *TotalLength;
 {
-    afs_int32 i, sn;
-    struct cell *tcell;
+    return ENOSYS;
+}
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
-    AFS_STATCNT(SRXAFSCB_GetCellByNum);
-
-    a_hosts->serverList_val = 0;
-    a_hosts->serverList_len = 0;
-
-    tcell = afs_GetCellStale(a_cellnum, READ_LOCK);
-    if (!tcell) {
-	*a_name = afs_strdup("");
-#ifdef RX_ENABLE_LOCKS
-	AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
-	return 0;
-    }
-
-    ObtainReadLock(&tcell->lock);
-    *a_name = afs_strdup(tcell->cellName);
-
-    for (sn = 0; sn < AFSMAXCELLHOSTS && tcell->cellHosts[sn]; sn++) 
-	;
-    a_hosts->serverList_len = sn;
-    a_hosts->serverList_val = (afs_int32 *) afs_osi_Alloc(sn*sizeof(afs_int32));
-
-    for (i = 0; i < sn; i++)
-	a_hosts->serverList_val[i] = ntohl(tcell->cellHosts[i]->addr->sa_ip);
-    ReleaseReadLock(&tcell->lock);
-    afs_PutCell(tcell, READ_LOCK);
-
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
-    return 0;
+/*------------------------------------------------------------------------
+ * EXPORTED SRXAFSCB_StoreData
+ *
+ * Description:
+ *      Routine to do third party move from a remioserver to the original
+ *      issuer of a RetrieveData request. Presently supported only by the
+ *      "fs" command, not by the AFS client.
+ *
+ * Arguments:
+ *      rxcall:        Ptr to Rx call on which this request came in.
+ *      Fid:           pointer to AFSFid structure.
+ *      Fd:            File descriptor inside fs command.
+ *      Position:      Offset in the file.
+ *      Length:        Data length to transfer.
+ *      TotalLength:   Pointer to total file length field
+ *
+ * Returns:
+ *      0 on success
+ *
+ * Environment:
+ *      Nothing interesting.
+ *
+ * Side Effects:
+ *      As advertised.
+ *------------------------------------------------------------------------*/
+SRXAFSCB_StoreData(rxcall, Fid, Fd, Position, Length, TotalLength)
+    struct rx_call *rxcall;
+    struct AFSFid *Fid;
+    afs_int32 Fd;
+    afs_int64 Position;
+    afs_int64 Length;
+    afs_int64 *TotalLength;
+{
+    return ENOSYS;
 }
- 
