@@ -16,7 +16,7 @@
 #include <afs/param.h>
 #endif
 
-RCSID("$Header: /cvs/openafs/src/auth/ktc.c,v 1.7.2.3 2003/07/01 19:36:41 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/auth/ktc.c,v 1.9 2001/11/21 15:29:52 shadow Exp $");
 
 #if defined(UKERNEL)
 #include "../afs/sysincludes.h"
@@ -131,10 +131,7 @@ static struct flock fileUlock = { F_UNLCK, 0, 0, 0, 0 };
  */
 int afs_tf_init(), afs_tf_get_pname(), afs_tf_get_pinst(), afs_tf_get_cred(); 
 int afs_tf_save_cred(), afs_tf_close(), afs_tf_create(); 
-int afs_tf_dest_tkt();
-/* except ktc_LocalCell which is still static
- */
-static int ktc_LocalCell();
+int afs_tf_dest_tkt(), ktc_LocalCell();
 char *ktc_tkt_string();
 #endif  /* AFS_KERBEROS_ENV */
 
