@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/butc/dump.c,v 1.6.2.3 2002/09/10 22:33:42 zacheiss Exp $");
+RCSID("$Header: /cvs/openafs/src/butc/dump.c,v 1.8 2002/03/10 19:07:59 shadow Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -101,7 +101,7 @@ afs_int32 tapeblocks;      /* Number of 16K tape datablocks in buffer (!CONF_XBS
    else \
      sprintf(dumpname, "%s (DumpId %u)", name, dbDumpId);
 
-#if defined(AFS_NT40_ENV) || (defined(AFS_DARWIN_ENV) && !defined(AFS_DARWIN60_ENV)) || defined(AFS_SUN4_ENV)
+#if defined(AFS_NT40_ENV) || defined(AFS_DARWIN_ENV)
 localtime_r(t, tm)
    time_t *t;
    struct tm *tm;
@@ -1501,7 +1501,6 @@ getDumpTape(dparamsPtr, interactiveFlag, append)
 
     extern struct tapeConfig globalTapeConfig;
     extern struct udbHandleS udbHandle;
-    extern afs_int32 BUDB_DeleteDump();
 
     askForTape = interactiveFlag;
     dparamsPtr->wroteLabel = 0;
