@@ -1,12 +1,3 @@
-/*
- * Copyright 2000, International Business Machines Corporation and others.
- * All Rights Reserved.
- * 
- * This software has been released under the terms of the IBM Public
- * License.  For details, see the LICENSE file in the top-level source
- * directory or online at http://www.openafs.org/dl/license10.html
- */
-
 #ifndef	AFS_PARAM_H
 #define	AFS_PARAM_H
 
@@ -25,10 +16,13 @@
 #define	AFS_SUN56_ENV		1
 #define AFS_SUN57_ENV		1
 #define AFS_SUN58_ENV		1
-#define AFS_SUN59_ENV		1
-#define AFS_X86_ENV		1
+#define AFS_X86_ENV             1
 
-#define AFS_64BIT_ENV		1       /* Defines afs_int32 as int, not long. */
+#ifdef AFS_NAMEI_ENV
+#define AFS_64BIT_IOPS_ENV     1       /* needed for NAMEI... */
+#else /* AFS_NAMEI_ENV */
+#define AFS_3DISPARES           1       /* Utilize the 3 available disk inode 'spares' */
+#endif /* AFS_NAMEI_ENV */
 
 #include <afs/afs_sysnames.h>
 
@@ -36,21 +30,15 @@
 #define RXK_LISTENER_ENV   1
 #define AFS_GCPAGS		1       /* if nonzero, garbage collect PAGs */
 
-#ifdef AFS_NAMEI_ENV
-#define AFS_64BIT_IOPS_ENV	1	/* needed for NAMEI... */
-#else /* AFS_NAMEI_ENV */
-#define	AFS_3DISPARES		1	/* Utilize the 3 available disk inode 'spares' */
-#endif /* AFS_NAMEI_ENV */
-
 #define	AFS_SYSCALL		65
 
 /* File system entry (used if mount.h doesn't define MOUNT_AFS */
 #define AFS_MOUNT_AFS	 "afs"
 
 /* Machine / Operating system information */
-#define sys_sunx86_59	1
-#define SYS_NAME	"sunx86_59"
-#define SYS_NAME_ID	SYS_NAME_ID_sunx86_59
+#define sys_sunx86_58	1
+#define SYS_NAME	"sunx86_58"
+#define SYS_NAME_ID	SYS_NAME_ID_sunx86_58
 #define AFSLITTLE_ENDIAN	1
 #define AFS_HAVE_FFS    1       /* Use system's ffs. */
 #define AFS_HAVE_VXFS	1	/* Support cache on Veritas vxfs file system */
@@ -85,26 +73,6 @@
 #define	AFS_MINCHANGE	2
 #define	osi_GetTime(x)	uniqtime(x)
 
-/**
-  * These defines are for the 64 bit Solaris 7 port
-  * AFS_SYSCALL32 is used to protect the ILP32 syscall interface
-  * AFS_64BIT_ENV is for use of 64 bit inode numbers
-  */
-#if defined(__sparcv9)
-#define	AFS_SUN57_64BIT_ENV	1
-#define AFS_64BIT_INO   	1
-#endif
-
-/**
-  * Solaris 7 64 bit has two versions of uniqtime. Since we consistently
-  * use 32 bit quantities for time in afs, we now use uniqtime32
-  */
-#if defined(AFS_SUN57_64BIT_ENV)
-#undef osi_GetTime
-#define osi_GetTime(x)  uniqtime32(x)
-#endif
-
-
 
 #define	AFS_KALLOC(n)	kmem_alloc(n, KM_SLEEP)
 #define AFS_KALLOC_NOSLEEP(n)   kmem_alloc(n, KM_NOSLEEP)
