@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/kauth/kaprocs.c,v 1.8.2.5 2004/10/18 04:59:07 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/kauth/kaprocs.c,v 1.10 2002/02/25 09:31:08 kolya Exp $");
 
 #include <afs/stds.h>
 #include <errno.h>
@@ -928,8 +928,7 @@ PrepareTicketAnswer
     afs_int32 cksum;
 
     code = KAANSWERTOOLONG;
-    if (oanswer->MaxSeqLen <
-	sizeof(struct ka_ticketAnswer) - 5 * MAXKTCNAMELEN - MAXKTCTICKETLEN + ticketLen)
+    if (oanswer->MaxSeqLen < sizeof(struct ka_ticketAnswer) - 5*MAXKTCNAMELEN)
 	return code;
 
     answer = (struct ka_ticketAnswer *)oanswer->SeqBody;
@@ -1708,11 +1707,6 @@ static afs_int32 GetTicket (version, call, kvno, authDomain, aticket,
     if (import && (celllen == 0)) {code = KABADTICKET; goto abort;}
     if (export && (celllen == 0)) strcpy (cell, lrealm);
 
-    if (!krb4_cross && celllen && strcmp(lrealm, cell) != 0) {
-      code = KABADUSER;
-      goto abort;
-    }
-
     des_ecb_encrypt (atimes->SeqBody, &times, schedule, DECRYPT);
     times.start = ntohl(times.start);
     times.end = ntohl(times.end);
@@ -1763,9 +1757,8 @@ static afs_int32 GetTicket (version, call, kvno, authDomain, aticket,
     switch (version) {
       case 0:
 	code = KAANSWERTOOLONG;
-        if (oanswer->MaxSeqLen < sizeof(struct ka_getTicketAnswer) - 5 
-	    * MAXKTCNAMELEN - MAXKTCTICKETLEN + ticketLen)
-	    goto abort;
+	if (oanswer->MaxSeqLen <
+	    sizeof(struct ka_getTicketAnswer) - 5*MAXKTCNAMELEN) goto abort;
 	
 	answer = (struct ka_getTicketAnswer *)oanswer->SeqBody;
 	memcpy(&answer->sessionKey, &sessionKey, sizeof(struct ktc_encryptionKey));
