@@ -15,14 +15,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/kauth/krb_udp.c,v 1.14.2.5 2002/09/10 22:33:49 zacheiss Exp $");
+RCSID("$Header: /cvs/openafs/src/kauth/krb_udp.c,v 1.17 2002/02/16 18:23:55 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
-#include <errno.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
-#include <afs/errmap_nt.h>
 #define snprintf _snprintf
 #else
 #include <sys/socket.h>
@@ -780,8 +778,6 @@ static SocketListener ()
 	    code = recvfrom(sock_kerb, packet.data, sizeof(packet.data), 0,
 			    (struct sockaddr *) &packet.from, &fromLen);
 	    if (code < 0) {
-		if (errno == EAGAIN || errno == ECONNREFUSED) 
-		    goto try_kerb5;
 		perror ("calling recvfrom");
 		break;
 	    }
@@ -796,13 +792,10 @@ static SocketListener ()
 	    packet.time = 0;
 	    process_udp_request (sock_kerb, &packet);
 	} 
-try_kerb5:
 	if ((sock_kerb5 >= 0) && FD_ISSET(sock_kerb5, &rfds)) {
 	    code = recvfrom(sock_kerb5, packet.data, sizeof(packet.data), 0,
 			    (struct sockaddr *) &packet.from, &fromLen);
 	    if (code < 0) {
-		if (errno == EAGAIN || errno == ECONNREFUSED) 
-		    continue;
 		perror ("calling recvfrom");
 		break;
 	    }
@@ -818,15 +811,6 @@ try_kerb5:
 	    process_udp_request (sock_kerb5, &packet);
 	} 
     }
-    if (sock_kerb >= 0) {
-	close(sock_kerb);
-	sock_kerb = -1;
-    }
-    if (sock_kerb5 >= 0) {
-	close(sock_kerb5);
-	sock_kerb5 = -1;
-    }
-    printf("UDP SocketListener exiting due to error\n");
 }
 
 #if MAIN
