@@ -14,7 +14,7 @@
 #include <afs/param.h>
 #endif
 
-RCSID("$Header: /cvs/openafs/src/rx/rx_packet.c,v 1.14.2.5 2003/01/17 05:42:34 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/rx/rx_packet.c,v 1.19 2002/02/16 18:23:59 shadow Exp $");
 
 #ifdef KERNEL
 #if defined(UKERNEL)
@@ -1471,15 +1471,14 @@ static void rxi_SendDebugPacket(struct rx_packet *apacket, osi_socket asocket,
 }
 
 /* Send the packet to appropriate destination for the specified
- * call.  The header is first encoded and placed in the packet.
+ * connection.  The header is first encoded and placed in the packet.
  */
-void rxi_SendPacket(struct rx_call * call, struct rx_connection * conn,
-		    struct rx_packet *p, int istack)
+void rxi_SendPacket(struct rx_connection * conn, struct rx_packet *p,
+		    int istack)
 {
 #if defined(KERNEL)
     int waslocked;
 #endif
-    int code;
     struct sockaddr_in addr;
     register struct rx_peer *peer = conn->peer;
     osi_socket socket;
@@ -1551,24 +1550,14 @@ void rxi_SendPacket(struct rx_call * call, struct rx_connection * conn,
 	waslocked = ISAFS_GLOCK();
 	if (waslocked) AFS_GUNLOCK();
 #endif
-	if ((code = osi_NetSend(socket, &addr, p->wirevec, p->niovecs, 
-				p->length+RX_HEADER_SIZE, istack)) != 0) {
+	if (osi_NetSend(socket, &addr, p->wirevec, p->niovecs, 
+			p->length+RX_HEADER_SIZE, istack)){
 	  /* send failed, so let's hurry up the resend, eh? */
 	  MUTEX_ENTER(&rx_stats_mutex);
 	  rx_stats.netSendFailures++;	   
 	  MUTEX_EXIT(&rx_stats_mutex);
 	  p->retryTime = p->timeSent;  /* resend it very soon */
 	  clock_Addmsec(&(p->retryTime), 10 + (((afs_uint32) p->backoff) << 8));
-
-#if defined(KERNEL) && defined(AFS_LINUX20_ENV)
-	  /* Linux is nice -- it can tell us right away that we cannot
-	   * reach this recipient by returning an ENETUNREACH error
-	   * code.  So, when this happens let's "down" the host NOW so
-	   * we don't sit around waiting for this host to timeout later.
-	   */
-	  if (call && code == -ENETUNREACH)
-	    call->lastReceiveTime = 0;
-#endif
 	}
 #ifdef KERNEL
 	if (waslocked) AFS_GLOCK();
@@ -1593,8 +1582,10 @@ void rxi_SendPacket(struct rx_call * call, struct rx_connection * conn,
 /* Send a list of packets to appropriate destination for the specified
  * connection.  The headers are first encoded and placed in the packets.
  */
-void rxi_SendPacketList(struct rx_call * call, struct rx_connection * conn,
-			struct rx_packet **list, int len, int istack)
+void rxi_SendPacketList(struct rx_connection * conn,
+			struct rx_packet **list,
+			int len,
+			int istack)
 {
 #if     defined(AFS_SUN5_ENV) && defined(KERNEL)
     int waslocked;
@@ -1604,7 +1595,7 @@ void rxi_SendPacketList(struct rx_call * call, struct rx_connection * conn,
     osi_socket socket;
     struct rx_packet *p = NULL;
     struct iovec wirevec[RX_MAXIOVECS];
-    int i, length, code;
+    int i, length;
     afs_uint32 serial;
     afs_uint32 temp;
     struct rx_jumboHeader *jp;
@@ -1724,7 +1715,7 @@ void rxi_SendPacketList(struct rx_call * call, struct rx_connection * conn,
 	waslocked = ISAFS_GLOCK();
 	if (!istack && waslocked) AFS_GUNLOCK();
 #endif
-	if ((code = osi_NetSend(socket, &addr, &wirevec[0], len+1, length, istack)) != 0){
+	if (osi_NetSend(socket, &addr, &wirevec[0], len+1, length, istack)){
 	  /* send failed, so let's hurry up the resend, eh? */
 	  MUTEX_ENTER(&rx_stats_mutex);
 	  rx_stats.netSendFailures++;	   
@@ -1734,15 +1725,6 @@ void rxi_SendPacketList(struct rx_call * call, struct rx_connection * conn,
 	    p->retryTime = p->timeSent;  /* resend it very soon */
 	    clock_Addmsec(&(p->retryTime), 10 + (((afs_uint32) p->backoff) << 8));
 	  }
-#if defined(KERNEL) && defined(AFS_LINUX20_ENV)
-	  /* Linux is nice -- it can tell us right away that we cannot
-	   * reach this recipient by returning an ENETUNREACH error
-	   * code.  So, when this happens let's "down" the host NOW so
-	   * we don't sit around waiting for this host to timeout later.
-	   */
-	  if (call && code == -ENETUNREACH)
-	    call->lastReceiveTime = 0;
-#endif
 	}
 #if	defined(AFS_SUN5_ENV) && defined(KERNEL)
 	if (!istack && waslocked) AFS_GLOCK();
@@ -1834,7 +1816,7 @@ rxi_SendSpecial(call, conn, optionalPacket, type, data, nbytes, istack)
     }
 
     if (call) rxi_Send(call, p, istack);
-    else rxi_SendPacket((struct rx_call *)0, conn, p, istack);
+    else rxi_SendPacket(conn, p, istack);
     if (saven) {  /* means we truncated the packet above.  We probably don't  */
       /* really need to do this, but it seems safer this way, given that  */
       /* sneaky optionalPacket... */
