@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/ubik/lock.c,v 1.7 2001/09/17 21:15:30 shadow Exp $");
+
 #include <sys/types.h>
 #ifndef AFS_NT40_ENV
 #include <sys/file.h>
@@ -58,7 +62,6 @@ ulock_getLock(atrans, atype, await)
   struct ubik_trans *atrans;
   int               atype, await;
 {
-  struct ubik_trans *tt;
   struct ubik_dbase *dbase=atrans->dbase;
 
   /* On first pass, initialize the lock */
@@ -114,6 +117,7 @@ ulock_getLock(atrans, atype, await)
 }
 
 /* Release the transaction lock */
+int
 ulock_relLock(atrans)
   struct ubik_trans *atrans;
 {
