@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/volser/volmain.c,v 1.7 2001/07/12 19:59:35 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/volser/volmain.c,v 1.9 2002/02/28 06:10:51 shadow Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -337,12 +337,11 @@ usage:
     }
     if (!rxJumbograms) {
 	/* Don't allow 3.4 vos clients to send jumbograms and we don't send. */
-	rx_maxReceiveSize = OLD_MAX_PACKET_SIZE;
-	rxi_nSendFrags = rxi_nRecvFrags = 1;
+        rx_SetNoJumbo();
     }
     rx_GetIFInfo();
     rx_SetRxDeadTime(420);
-    bzero(busyFlags, sizeof(busyFlags));
+    memset(busyFlags, 0, sizeof(busyFlags));
 
     /* Open FileLog and map stdout, stderr into it */
     OpenLog(AFSDIR_SERVER_VOLSERLOG_FILEPATH);
